/**
 * @description slice() 方法返回一个新的数组对象，这一对象是一个由 begin 和 end 决定的原数组的浅拷贝（包括 begin，不包括end）。原始数组不会被改变。
 * @param {*} array
 * @param {*} begin 提取起始处的索引
 * @param {*} end 提取终止处的索引
 */
export default function slice(array, begin, end) {
  var result = [];
  // 如果省略 begin，则 从索引 0 开始
  begin = begin || 0;
  // 如果该参数为负数，则表示从原数组中的倒数第几个元素开始提取
  if (begin < 0) {
    begin = array.length + begin;
  }
  // 如果 end 被省略，就等于数组的长度
  end = end || array.length;
  // 如果 begin 超出原数组的索引范围，则会返回空数组
  if (begin > array.length) {
    return [];
  }
  // 如果 end 大于数组的长度，那么end = 数组长度
  if (end > array.length) {
    end = array.length;
  }
  // 如果begin比end大返回空数组
  if (begin > end) {
    return [];
  }
  for (let i = begin; i < end; i++) {
    result.push(array[i]);
  }
  return result;
}

// const animals = ["ant", "bison", "camel", "duck", "elephant"];

// console.log(slice(animals, 2));
// console.log(slice(animals, 2, 4));
// console.log(slice(animals, 1, 5));
// console.log(slice(animals, -2, 5));
// console.log(slice(animals, 6));
// console.log(slice(animals, 4, 1));
