/**
 * @description 通过双层循环去重，性能较差
 * @param {*} array
 */
export function unique1(array) {
  // 声明一个新数组
  let result = [];
  // 循环数组
  for (let i = 0; i < array.length; i++) {
    let current = array[i];
    // 通过indexOf检测当前项是否在result中，不在就插入到result
    if (result.indexOf(current) === -1) {
      result.push(array[i]);
    }
  }
  return result;
}

/**
 * @description 通过增加一个对象，进行去重，性能较好
 * @param {*} array
 */
export function unique2(array) {
  // 声明一个对象
  let obj = {};
  // 声明一个新数组
  let result = [];
  // 循环数组
  for (let i = 0; i < array.length; i++) {
    // 如果对象中没有这个key值，向新数组插入，并给对象添加这个key
    let key = array[i];
    if (!obj[key]) {
      result.push(key);
      obj[key] = true;
    }
  }
  return result;
}

/**
 * @description 通过Set的特性进行去重
 * @param {*} array
 */
export function unique3(array) {
  return [...new Set(array)];
}

export default {
  unique1,
  unique2,
  unique3,
};
